@@ -380,7 +380,7 @@ class RundeckJobs(object):
                      "-tag_names", f"{os.environ.get('RD_OPTION_TAG_NAMES')}",
                      "-auto_apply", f"{auto_apply}",
                      "-execution_mode", f"{execution_mode}"],
-                )
+                    cwd=config_dir_location, check=True)
 
         elif deployment_action == "destroy":
             # zx.run_shell_print(f"cd {config_dir_location} && \
